# 2022-08-23 - Arbitrum Root Gauge Factory V2

Deployment of the `ArbitrumRootGaugeFactory`, for stakeless gauges that bridge funds to their Arbitrum counterparts. This updated version includes caps on the relative weight (allocated emissions) for each gauge.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [`ArbitrumRootGauge` artifact](./artifact/ArbitrumRootGauge.json)
- [`ArbitrumRootGaugeFactory` artifact](./artifact/ArbitrumRootGaugeFactory.json)
